==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/simpledatatypes/rev20131112/SimpleDataTypesOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.simpledatatypes.rev20131112;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.simpledatatypes.rev20131112.simpledatatypes.Cont;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of simpleDataTypes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class SimpleDataTypesOpParam extends InnerModelObject implements SimpleDataTypes {
    protected Cont cont;

    @Override
    public Cont cont() {
        return cont;
    }

    @Override
    public void cont(Cont cont) {
        this.cont = cont;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cont);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SimpleDataTypesOpParam) {
            SimpleDataTypesOpParam other = (SimpleDataTypesOpParam) obj;
            return
                Objects.equals(cont, other.cont);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("cont=" + cont)
            .toString();
    }

    /**
     * Creates an instance of simpleDataTypesOpParam.
     */
    public SimpleDataTypesOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/simpledatatypes/rev20131112/SimpleDataTypesOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.simpledatatypes.rev20131112;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.simpledatatypes.rev20131112.simpledatatypes.Cont;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of simpleDataTypes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class SimpleDataTypesOpParam extends InnerModelObject implements SimpleDataTypes {
    protected Cont cont;

    @Override
    public Cont cont() {
        return cont;
    }

    @Override
    public void cont(Cont cont) {
        this.cont = cont;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cont);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SimpleDataTypesOpParam) {
            SimpleDataTypesOpParam other = (SimpleDataTypesOpParam) obj;
            return
                Objects.deepEquals(cont, other.cont);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("cont=" + cont)
            .toString();
    }

    /**
     * Creates an instance of simpleDataTypesOpParam.
     */
    public SimpleDataTypesOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}
